@@ -374,62 +374,66 @@ tbill_model <- lm(Tbill3mo ~ cpi + deficit, data = intdef.xts)
 ## ---- results='asis', echo=FALSE, warning=FALSE, message=FALSE----------------
 stargazer(type = "html",tbill_model, single.row = TRUE, header = FALSE, digits=5)
 
-## ----message=FALSE, warning=FALSE---------------------------------------------
-library(quantmod)
+## ----eval=FALSE, FALSE, message=FALSE, warning=FALSE--------------------------
+#  # DO NOT RUN
+#  library(quantmod)
+#  
+#  # Tbill, 3 month
+#  getSymbols("TB3MS", src = "FRED")
+#  # convert to annual observations and convert index to type `yearmon`.
+#  TB3MS <- to.yearly(TB3MS, OHLC=FALSE, drop.time = TRUE)
+#  index(TB3MS) <- zoo::as.yearmon(index(TB3MS))
+#  
+#  # Inflation
+#  getSymbols("FPCPITOTLZGUSA", src = "FRED")
+#  # Convert the index to yearmon and shift FRED's Jan 1st to Dec
+#  index(FPCPITOTLZGUSA) <- zoo::as.yearmon(index(FPCPITOTLZGUSA)) + 11/12
+#  # Rename and update column names
+#  inflation <- FPCPITOTLZGUSA
+#  colnames(inflation) <- "inflation"
+#  
+#  ## Deficit, percent of GDP: Federal outlays - federal receipts
+#   # Download outlays
+#  getSymbols("FYFRGDA188S", src = "FRED")
+#   # Lets move the index from Jan 1st to Dec 30th/31st
+#  index(FYFRGDA188S) <- zoo::as.yearmon(index(FYFRGDA188S)) + 11/12
+#   # Rename and update column names
+#  outlays <- FYFRGDA188S
+#  colnames(outlays) <- "outlays"
+#  
+#   # Download receipts
+#  getSymbols("FYONGDA188S", src = "FRED")
+#   # Lets move the index from Jan 1st to Dec 30th/31st
+#  index(FYONGDA188S) <- zoo::as.yearmon(index(FYONGDA188S)) + 11/12
+#   # Rename and update column names
+#  receipts <- FYONGDA188S
+#  colnames(receipts) <- "receipts"
 
-# Tbill, 3 month
-getSymbols("TB3MS", src = "FRED")
-# convert to annual observations and convert index to type `yearmon`.
-TB3MS <- to.yearly(TB3MS, OHLC=FALSE, drop.time = TRUE)
-index(TB3MS) <- zoo::as.yearmon(index(TB3MS))
+## ----eval=FALSE, message=FALSE, warning=FALSE---------------------------------
+#  # DO NOT RUN
+#  # create deficits from outlays - receipts
+#  # xts objects respect their indexing and outline the future
+#  deficit <- outlays - receipts
+#  colnames(deficit) <- "deficit"
+#  
+#  # Merge and remove leading and trailing NAs for a balanced data matrix
+#  intdef_updated <- merge(TB3MS, inflation, deficit)
+#  intdef_updated <- zoo::na.trim(intdef_updated)
+#  
+#  #Plot all
+#  plot(intdef_updated,
+#       main = "T-bill (3mo rate), inflation, and deficit (% of GDP)",
+#       legend.loc = "topright",)
 
-# Inflation
-getSymbols("FPCPITOTLZGUSA", src = "FRED")
-# Convert the index to yearmon and shift FRED's Jan 1st to Dec
-index(FPCPITOTLZGUSA) <- zoo::as.yearmon(index(FPCPITOTLZGUSA)) + 11/12
-# Rename and update column names
-inflation <- FPCPITOTLZGUSA
-colnames(inflation) <- "inflation"
+## ----eval=FALSE---------------------------------------------------------------
+#  # DO NOT RUN
+#  updated_model <- lm(TB3MS ~ inflation + deficit, data = intdef_updated)
 
-## Deficit, percent of GDP: Federal outlays - federal receipts
- # Download outlays
-getSymbols("FYFRGDA188S", src = "FRED")
- # Lets move the index from Jan 1st to Dec 30th/31st
-index(FYFRGDA188S) <- zoo::as.yearmon(index(FYFRGDA188S)) + 11/12
- # Rename and update column names
-outlays <- FYFRGDA188S
-colnames(outlays) <- "outlays"
-
- # Download receipts
-getSymbols("FYONGDA188S", src = "FRED")
- # Lets move the index from Jan 1st to Dec 30th/31st
-index(FYONGDA188S) <- zoo::as.yearmon(index(FYONGDA188S)) + 11/12
- # Rename and update column names
-receipts <- FYONGDA188S
-colnames(receipts) <- "receipts"
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-# create deficits from outlays - receipts
-# xts objects respect their indexing and outline the future
-deficit <- outlays - receipts
-colnames(deficit) <- "deficit"
-
-# Merge and remove leading and trailing NAs for a balanced data matrix
-intdef_updated <- merge(TB3MS, inflation, deficit)
-intdef_updated <- zoo::na.trim(intdef_updated)
-
-#Plot all
-plot(intdef_updated, 
-     main = "T-bill (3mo rate), inflation, and deficit (% of GDP)",
-     legend.loc = "topright",)
-
-## -----------------------------------------------------------------------------
-updated_model <- lm(TB3MS ~ inflation + deficit, data = intdef_updated)
-
-## ---- results='asis', echo=FALSE, warning=FALSE, message=FALSE----------------
-updated_model <- lm(TB3MS ~ inflation + deficit, data = intdef_updated)
-
-stargazer(type = "html", updated_model, single.row = TRUE, header = FALSE, digits=5)
+## ---- eval=FALSE, results='asis', echo=FALSE, warning=FALSE, message=FALSE----
+#  #DO NOT RUN
+#  updated_model <- lm(TB3MS ~ inflation + deficit, data = intdef_updated)
+#  
+#  stargazer(type = "html", updated_model, single.row = TRUE, header = FALSE, digits=5)
 
 ## ---- message=FALSE-----------------------------------------------------------
 data("earns")
